@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Gufw 12.10.0 - http://gufw.tuxfamily.org
+# Gufw 13.04.0 - http://gufw.org
 # Copyright (C) 2008-2011 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -422,6 +422,18 @@ class Gufw_daemon(dbus.service.Object):
         commands.getstatusoutput("echo 'log=&' >> /etc/gufw/gufw.cfg".replace('&', gufw_logging))
         commands.getstatusoutput("echo 'listening=&' >> /etc/gufw/gufw.cfg".replace('&', listening_status))
         commands.getstatusoutput("echo 'notify_popup=&' >> /etc/gufw/gufw.cfg".replace('&', notify_popup))
+
+    @dbus.service.method("gufw.SampleInterface",
+                     in_signature='', out_signature='',
+                     sender_keyword='sender', connection_keyword='conn')
+    def set_donate_file(self, sender=None, conn=None):
+        """Save actual FW config when quit Gufw"""
+        dbus_info_aux = dbus.Interface(conn.get_object('org.freedesktop.DBus', '/org/freedesktop/DBus/Bus', False), 'org.freedesktop.DBus')
+        if ( self.__caller_pid__ == 0 ) or ( self.__caller_pid__ != dbus_info_aux.GetConnectionUnixProcessID(sender) ):
+            return
+            
+        commands.getstatusoutput("mkdir /etc/gufw")
+        commands.getstatusoutput("echo 'hide' >> /etc/gufw/hide_donate")
     
     @dbus.service.method("gufw.SampleInterface",
                      in_signature='bsssssssss', out_signature='s',
