@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Gufw 12.10.0 - http://gufw.tuxfamily.org
+# Gufw 13.04.0 - http://gufw.org
 # Copyright (C) 2008-2011 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -107,6 +107,7 @@ class GuiGufw:
         self.menu_reset     = builder.get_object("menuReset")
         self.menu_pref      = builder.get_object("menuPreferences")
         self.menu_doc       = builder.get_object("menuDoc")
+        self.menu_donate    = builder.get_object("menuDonate")
         self.menu_answers   = builder.get_object("menuAnswers")
         self.menu_bug       = builder.get_object("menuBug")
         self.menu_translate = builder.get_object("menuTranslate")
@@ -116,9 +117,19 @@ class GuiGufw:
         self.menu_quit.connect('activate', self.on_menuQuit_activate)
         self.menu_about.connect('activate', self.on_menuAbout_activate)
         self.btn_unlock.connect('clicked', self.on_btnUnlock_clicked)
+        
+        # Donate box
+        self.donate_box = builder.get_object("donate_box")
+        if not self.fw.get_donate_file_exists():
+            self.btnHideDonate = builder.get_object("btnHideDonate")
+        else:
+            self.donate_box.hide()
+        
         # Show Listening report
         if self.fw.get_listening_status() == "enable":
             self.block_report.show()
+        else:
+            self.block_report.hide()
         # Focus
         self.btn_unlock.grab_focus()
             
@@ -214,7 +225,7 @@ class GuiGufw:
         self.rules_notebook   = builder.get_object("rulesNotebook")
         self.add_btn_add      = builder.get_object("btnAddRule")
         self.extended_actions = builder.get_object("cbExtendedActions")
-        
+
     def _set_ui_preferences(self, builder):
         """Set the window Preferences"""
         builder.add_from_file(self.path.get_ui_path('preferences.ui'))
@@ -778,6 +789,11 @@ class GuiGufw:
         task = self._remove_rule()
         GObject.idle_add(task.next)
     
+    def btnHideDonate_clicked_cb(self, widget):
+        """Hide Donate button forever"""
+        self.donate_box.hide()
+        self.fw.set_donate_file()
+    
     def on_btnAddRule_clicked(self, widget):
         """Add rule Button"""
         # Simple rule
@@ -821,6 +837,7 @@ class GuiGufw:
         self.btn_add_window.set_sensitive(True)
         # Problems with Glade events
         self.menu_doc.set_sensitive(True)
+        self.menu_donate.set_sensitive(True)
         self.menu_answers.set_sensitive(True)
         self.menu_bug.set_sensitive(True)
         self.menu_translate.set_sensitive(True)
@@ -845,6 +862,9 @@ class GuiGufw:
             self.cb_policy_outgoing.set_active(1)
         elif outgoing == "allow":
             self.cb_policy_outgoing.set_active(2)
+        # Others
+        if not self.fw.get_donate_file_exists():
+            self.btnHideDonate.set_sensitive(True)
     
     def _set_initial_objects_preferences(self):
         """Set the initial "locked" status"""
@@ -1028,10 +1048,10 @@ class GuiGufw:
     def on_menuAbout_activate(self, widget):
         """View About Window"""
         about = Gtk.AboutDialog()
-        about.set_copyright(_("© 2008-2012 The Gufw Project\nShield logo © 2007 Michael Spiegel"))
+        about.set_copyright(_("© 2008-2013 The Gufw Project\nShield logo © 2007 Michael Spiegel"))
         about.set_comments(_("Graphical user interface for ufw"))
-        about.set_version("12.10.0")
-        about.set_website("http://gufw.tuxfamily.org/")
+        about.set_version("13.04.0")
+        about.set_website("http://gufw.org")
         about.set_authors([_('''Lead developer:
 Marcos Alvarez Costales https://launchpad.net/~costales
 
@@ -1113,6 +1133,10 @@ http://www.gnu.org/licenses''')
         """Launch browser with Documentation web"""
         webbrowser.open_new("https://help.ubuntu.com/community/Gufw")
         
+    def on_menuDonate_activate(self, widget):
+        """Launch browser with Documentation web"""
+        webbrowser.open_new("http://gufw.org/donate")
+        
     def on_menuAnswers_activate(self, widget):
         """Launch browser with Documentation web"""
         webbrowser.open_new("https://answers.launchpad.net/gui-ufw")
